@@ -22,8 +22,39 @@
 #include <QtDBus>
 #include "mainwindow.h"
 
+
+
+
+
+void myMessageOutput(QtMsgType type, const char *msg)
+ {
+     switch (type) {
+     case QtDebugMsg:
+         fprintf(stderr, "===== Debug: %s\n", msg);
+         break;
+     case QtWarningMsg:
+   //      fprintf(stderr, "===== Warning: %s\n", msg); //disabled, we dont want to see anoying warnings
+         break;
+     case QtCriticalMsg:
+         fprintf(stderr, "===== Critical: %s\n", msg);
+         break;
+     case QtFatalMsg:
+         fprintf(stderr, "===== Fatal: %s\n", msg);
+         abort();
+     }
+ }
+
+
+
+
+
+
+
 int main(int argc, char *argv[])
 {
+    qInstallMsgHandler(myMessageOutput); //use our own message handlers
+    qDebug() << "Fahrplan start ===============================================";
+
     QApplication a(argc, argv);
 
     Q_INIT_RESOURCE(fahrplan);
@@ -52,10 +83,16 @@ int main(int argc, char *argv[])
         exit(3);
     }
 
+
+
+
 #if defined(Q_WS_S60)
     w.showMaximized();
 #else
     w.show();
 #endif
+
+    qDebug() << "Initialisation done ====================";
+
     return a.exec();
 }
