@@ -51,7 +51,7 @@
 #include "configdialog.h"
 #include "qvaluebutton.h"
 
-#define APP_VER "0.0.29"
+#define APP_VER "0.0.30"
 #define APP_FIRSTLAUNCH false
 
 #ifdef Q_WS_MAEMO_5
@@ -124,7 +124,7 @@ private:
     QDial *progressbarResult;
     QScrollArea *scrollAreaResult;
     QTimer *timer;
-    int progress;
+    bool timeout;
     bool locationDataSourceIsUpdating;
 
 
